@@ -28,12 +28,9 @@
 #include <string.h>
 #include <gst/gst.h>
 
-#include <libavcodec/avcodec.h>
-#include <libavformat/avformat.h>
-#include <libavfilter/avfiltergraph.h>
-
 #include "gstav.h"
 #include "gstavutils.h"
+#include "gstavcfg.h"
 
 #ifdef GST_LIBAV_ENABLE_GPL
 #define LICENSE "GPL"
@@ -51,7 +48,7 @@ static GMutex gst_avcodec_mutex;
 static inline gboolean
 gst_ffmpeg_avcodec_is_ffmpeg (void)
 {
-  guint av_version = avutil_version ();
+  guint av_version = avcodec_version ();
 
   GST_DEBUG ("Using libavcodec version %d.%d.%d",
       av_version >> 16, (av_version & 0x00ff00) >> 8, av_version & 0xff);
@@ -64,7 +61,7 @@ gst_ffmpeg_avcodec_is_ffmpeg (void)
 }
 
 int
-gst_ffmpeg_avcodec_open (AVCodecContext * avctx, AVCodec * codec)
+gst_ffmpeg_avcodec_open (AVCodecContext * avctx, const AVCodec * codec)
 {
   int ret;
 
@@ -75,18 +72,6 @@ gst_ffmpeg_avcodec_open (AVCodecContext * avctx, AVCodec * codec)
   return ret;
 }
 
-int
-gst_ffmpeg_avcodec_close (AVCodecContext * avctx)
-{
-  int ret;
-
-  g_mutex_lock (&gst_avcodec_mutex);
-  ret = avcodec_close (avctx);
-  g_mutex_unlock (&gst_avcodec_mutex);
-
-  return ret;
-}
-
 int
 gst_ffmpeg_av_find_stream_info (AVFormatContext * ic)
 {
@@ -155,8 +140,8 @@ plugin_init (GstPlugin * plugin)
 
   gst_ffmpeg_init_pix_fmt_info ();
 
-  av_register_all ();
-  avfilter_register_all ();
+  /* build global ffmpeg param/property info */
+  gst_ffmpeg_cfg_init ();
 
   gst_ffmpegaudenc_register (plugin);
   gst_ffmpegvidenc_register (plugin);
@@ -165,12 +150,7 @@ plugin_init (GstPlugin * plugin)
   gst_ffmpegdemux_register (plugin);
   gst_ffmpegmux_register (plugin);
   gst_ffmpegdeinterlace_register (plugin);
-#if 0
-  gst_ffmpegscale_register (plugin);
-#endif
-#if 0
-  gst_ffmpegaudioresample_register (plugin);
-#endif
+  gst_ffmpegvidcmp_register (plugin);
 
   /* Now we can return the pointer to the newly created Plugin object. */
   return TRUE;
